Module client

Module client 

Structs

Client
Splitwise API client.
CommentsSvc
Comments.
ExpensesSvc
Expenses.
FriendsSvc
Friends.
GroupsSvc
A Group represents a collection of users who share expenses together. For example, some users use a Group to aggregate expenses related to an apartment. Others use it to represent a trip. Expenses assigned to a group are split among the users of that group. Importantly, two users in a Group can also have expenses with one another outside of the Group.
NotificationsSvc
Notifications.
OtherSvc
Other.
UsersSvc
Resources to access and modify user information.