pub struct UpdateExpenseRequest {
pub cost: Option<String>,
pub description: Option<String>,
pub details: Option<String>,
pub date: Option<DateTime<Utc>>,
pub repeat_interval: Option<String>,
pub currency_code: Option<String>,
pub category_id: Option<i64>,
pub group_id: i64,
pub users: Option<Vec<UserShare>>,
}Expand description
Splitwise update_expense request.
Fields
cost: Option<String>A string representation of a decimal value, limited to 2 decimal places.
description: Option<String>A short description of the expense.
details: Option<String>Also known as “notes.”
date: Option<DateTime<Utc>>The date and time the expense took place. May differ from created_at.
repeat_interval: Option<String>Cadence at which the expense repeats. One of:
neverweeklyfortnightlymonthlyyearly
currency_code: Option<String>A currency code. Must be in the list from get_currencies.
category_id: Option<i64>A category id from get_categories.
group_id: i64The group to put this expense in.
users: Option<Vec<UserShare>>Users by share if not splitting the expense equally.